/*
 * @(#)TellMessage.java
 *
 * Copyright (c) 2004-2014, Erik C. Thauvin (erik@thauvin.net)
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * Neither the name of the author nor the names of its contributors may be
 * used to endorse or promote products derived from this software without
 * specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package net.thauvin.erik.mobibot;

import java.io.Serializable;
import java.util.Calendar;
import java.util.Date;

/**
 * The <code>TellMessage</code> class.
 *
 * @author <a href="mailto:erik@thauvin.net">Erik C. Thauvin</a>
 * @created 2014-04-24
 * @since 1.0
 */
public class TellMessage implements Serializable
{
	private static final long serialVersionUID = 1L;

	private final String sender;

	private final String recipient;

	private final String message;

	private final String id;

	final private Date queued;

	private Date received;

	private boolean isReceived;

	private boolean isNotified;

	/**
	 * Create a new message.
	 *
	 * @param sender The sender's nick.
	 * @param recipient The recipient's nick.
	 * @param message The message.
	 */
	public TellMessage(String sender, String recipient, String message)
	{
		this.sender = sender;
		this.recipient = recipient;
		this.message = message;

		this.queued = Calendar.getInstance().getTime();
		this.id = Utils.TIMESTAMP_SDF.format(this.queued);

	}

	public String getSender()
	{
		return sender;
	}

	public String getRecipient()
	{
		return recipient;
	}

	public String getMessage()
	{
		return message;
	}

	public Date getQueued()
	{
		return queued;
	}

	public Date getReceived()
	{
		return received;
	}

	public void setReceived()
	{
		this.received = Calendar.getInstance().getTime();
		this.isReceived = true;
	}

	public boolean isNotified()
	{
		return this.isNotified;
	}

	public void setNotified()
	{
		this.isNotified = true;
	}

	public String getId()
	{
		return this.id;
	}

	public boolean isReceived()
	{
		return this.isReceived;
	}

	public boolean isMatchId(String id)
	{
		return this.id.equals(id);
	}

	public boolean isMatch(String nick)
	{
		return (sender.equalsIgnoreCase(nick) || recipient.equalsIgnoreCase(nick));
	}
}